#
# spec file for package python-poetry-plugin-export
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}
%if "%{flavor}" == "test"
%define psuffix -test
%bcond_without test
%else
%define psuffix %{nil}
%bcond_with test
%endif

%{?sle15_python_module_pythons}
Name:           python-poetry-plugin-export%{psuffix}
Version:        1.8.0
Release:        1.3
Summary:        Poetry plugin to export the dependencies to various formats
License:        MIT
URL:            https://python-poetry.org/
# RepositorySource: https://github.com/python-poetry/poetry-plugin-export
Source:         https://files.pythonhosted.org/packages/source/p/poetry-plugin-export/poetry_plugin_export-%{version}.tar.gz
BuildRequires:  %{python_module base >= 3.8}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module poetry-core >= 1.7.0 with %python-poetry-core < 3}
# No buildtime requirement of poetry: avoid build dep cycles!
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
%if %{with test}
BuildRequires:  %{python_module build}
BuildRequires:  %{python_module installer}
BuildRequires:  %{python_module poetry-plugin-export = %{version}}
BuildRequires:  %{python_module pytest-mock}
BuildRequires:  %{python_module pytest-xdist}
BuildRequires:  %{python_module pytest}
%endif
Requires:       (python-poetry >= 1.8.0 with python-poetry < 3)
Requires:       (python-poetry-core >= 1.7.0 with python-poetry-core < 3)
Provides:       python-poetry_plugin_export = %{version}-%{release}
BuildArch:      noarch
%python_subpackages

%description
Poetry plugin to export the dependencies to various formats

%prep
%setup -q -n poetry_plugin_export-%{version}

%if !%{with test}
%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}
%endif

%if %{with test}
%check
%pytest
%endif

%if !%{with test}
%files %{python_files}
%doc README.md
%license LICENSE
%{python_sitelib}/poetry_plugin_export
%{python_sitelib}/poetry_plugin_export-%{version}.dist-info
%endif

%changelog
* Mon Nov  4 2024 Ben Greiner <code@bnavigator.de>
- Update to 1.8.0
  [#]# Changed
  * Relax the constraint on poetry and poetry-core to allow
    (future) 2.* versions (#280).
  [#]# Fixed
  * Fix an issue where editable installs where not exported
    correctly (#258).
- Release 1.7.1
  [#]# Changed
  * Export --index-url before --extra-index-url to work around a
    pip bug (#270).
  [#]# Fixed
  * Fix an issue where the source with the highest priority was
    exported with --index-url despite PyPI being among the sources
    (#270).
- Release 1.7.0
  [#]# Changed
  * Bump minimum required poetry version to 1.8.0 (#263).
  [#]# Fixed
  * Fix an issue where all sources were exported with
  - -extra-index-url even though PyPI was deactivated (#263).
* Thu Dec 14 2023 Dirk Müller <dmueller@suse.com>
- update to 1.6.0:
  * Add an --all-extras option
* Sat Sep 23 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.5.0
  [#]# Changed
  * Drop support for Python 3.7 (#189).
  * Improve warning when the lock file is not consistent with
    pyproject.toml (#215).
  [#]# Fixed
  * Fix an issue where markers for dependencies required by an
    extra were not generated correctly (#209).
* Mon May 29 2023 Ben Greiner <code@bnavigator.de>
- Update to 1.4.0
  * Fix an issue where --extra-index-url and --trusted-host was not
    generated for sources with priority explicit (#205).
* Mon May  8 2023 Johannes Kastl <kastl@b1-systems.de>
- add sle15_python_module_pythons
* Mon Apr 24 2023 Torsten Gruner <simmphonie@opensuse.org>
- Update to 1.3.1
  * This release mainly fixes test suite compatibility with
    upcoming Poetry releases.
  * Improve error message in some cases when the dependency walk fails (#184).
- Version 1.3.0
  * Drop some compatibility code and bump minimum required
    poetry version to 1.3.0 (#167).
  * Fix an issue where the export failed if there was a circular
    dependency on the root package (#118).
* Wed Dec 14 2022 Benjamin Greiner <code@bnavigator.de>
- Bump requirements
* Wed Dec 14 2022 Daniel Garcia <daniel.garcia@suse.com>
- Update to 1.2.0
  * Drop some compatibility code and bump minimum required poetry version to
    1.2.2 (#143).
  * Ensure compatibility with upcoming Poetry releases (#151).
* Mon Oct 10 2022 Ben Greiner <code@bnavigator.de>
- Update to 1.1.2
  * Fix an issue where exporting a constraints.txt file fails if an
    editable dependency is locked (#140).
* Sun Oct  9 2022 Ben Greiner <code@bnavigator.de>
- Initial specfile for v1.1.1
- Required by poetry 1.2
